pub enum IndexExprResult {
Exact(RowAddrMask),
AtMost(RowAddrMask),
AtLeast(RowAddrMask),
}Expand description
Result of an index search after NULL rows have been dropped. This is what the read planner consumes.
Variants
Exact(RowAddrMask)
The answer is exactly the rows in the allow list minus the rows in the block list.
AtMost(RowAddrMask)
The answer is at most the rows in the allow list minus the rows in the block list. Some of the rows in the allow list may not be in the result and will need to be filtered by a recheck. Every row in the block list is definitely not in the result.
AtLeast(RowAddrMask)
The answer is at least the rows in the allow list minus the rows in the block list. Some of the rows in the block list might be in the result. Every row in the allow list is definitely in the result.
Implementations
Sourceimpl IndexExprResult
impl IndexExprResult
pub fn row_addr_mask(&self) -> &RowAddrMask
pub fn discriminant(&self) -> u32